@@ -10,6 +10,8 @@ from discord import app_commands
 
 print(f"Importing {os.path.basename(__file__)}...")
 
+BOT_CHANNEL = 1073943829192912936
+
 
 class SetupCog(commands.Cog):
     """Add anything related to setting up bot here"""
@@ -19,13 +21,12 @@ class SetupCog(commands.Cog):
         super().__init__()
 
     @commands.command(name="sync")
-    @commands.has_role("Shiny")
     async def sync_command(self, context: commands.Context) -> None:
         """Add slash commands to Discord guid"""
         if platform.node().lower() == "secureerase":
             await context.defer()
             if importlib.metadata.version("shiny_api") != luddite.get_version_pypi("shiny_api"):
-                os._exit(1)
+                os._exit(1)  # pylint: disable=protected-access
             await asyncio.sleep(2)
 
         try:
@@ -54,7 +55,7 @@ class SetupCog(commands.Cog):
     )
     async def clear_command(self, context: discord.Interaction, scope: str):
         """Clear all or bot messages in bot-config"""
-        if context.channel.id != 1073943829192912936:
+        if context.channel.id != BOT_CHANNEL:
             await context.channel.send("Cannot use in this channel")
             return
         temp_message = await context.channel.send(f"Clearing messages from {scope}")
@@ -77,9 +78,16 @@ class SetupCog(commands.Cog):
     @commands.Cog.listener("on_ready")
     async def set_dev_rol(self):
         """Add dev role to activate bot if run from dev machine"""
-        if platform.node().lower() == "chris-mbp":
-            role = discord.utils.get(self.client.guilds[0].roles, name="Dev")
-            bot_member = discord.utils.get(self.client.get_all_members(), name="Doug Bot")
+        self.client.tree.copy_global_to(guild=self.client.guilds[0])
+        synced = await self.client.tree.sync(guild=self.client.guilds[0])
+        print(f"Synced {len(synced)} commands from {platform.node()}.")
+        role = discord.utils.get(self.client.guilds[0].roles, name="Dev")
+        bot_member = discord.utils.get(self.client.get_all_members(), name="Doug Bot")
+        if platform.node().lower() == "secureerase":
+            print("Switching to Prod")
+            await bot_member.remove_roles(role)
+        else:
+            print("Switching to Dev")
             await bot_member.add_roles(role)
 
 
